Crate iterate_and_spike_traits Copy item path Source CurrentVoltage Derive macro to automatically implement the CurrentVoltage trait assuming the
struct has field current_voltage IsSpiking Derive macro to automatically implement the IsSpiking trait assuming the
struct has field is_spiking IterateAndSpikeBase Derive macro to automatically implement many necessary traits for the IterateAndSpike trait,
including CurrentVoltage, GapConductance, Timestep, GaussianFactor,
LastFiringTime, and IsSpiking LastFiringTime Derive macro to automatically implement the LastFiringTime trait assuming the
struct has field last_firing_time SpikeTrainBase Derive macro to automatically implement many necessary traits for the SpikeTrain trait,
including CurrentVoltage, LastFiringTime, and IsSpiking Timestep Derive macro to automatically implement the Timestep trait assuming the
struct has field dt